==> 0.0.16.tar.gz: ios/Classes/SwiftSpectusPayumoneyPlugin.swift <==
import Flutter
import UIKit

public class SwiftSpectusPayumoneyPlugin: NSObject, FlutterPlugin {
  public static func register(with registrar: FlutterPluginRegistrar) {
    let channel = FlutterMethodChannel(name: "spectus_payumoney_plugin", binaryMessenger: registrar.messenger())
    let instance = SwiftSpectusPayumoneyPlugin()
    registrar.addMethodCallDelegate(instance, channel: channel)
  }

  public func handle(_ call: FlutterMethodCall, result: @escaping FlutterResult) {
          if (call.method == "getPlatformVersion") {
              result("iOS " + UIDevice.current.systemVersion)
          }
          else if (call.method == "payUmoneyPayment") {
              //result("\(checkiOSReturn())")
              if let topVC = UIApplication.shared.windows[0].rootViewController {

                  guard let args = call.arguments else {
                      return
                  }
                  if let myArgs = args as? [String: Any], let amountVal = myArgs["amount"] as? String,let merchantIDVal = myArgs["merchantID"] as? String,let merchantKeyVal = myArgs["merchantKey"] as? String,let saltVal = myArgs["salt"] as? String, let nameVal = myArgs["name"] as? String, let productInfoVal = myArgs["productInfo"] as? String, let emailVal = myArgs["email"] as? String, let mobileVal = myArgs["mobile"] as? String, let isProductionVal = myArgs["environmentMode"] as? Int {
                                      startPaymentWithAmount(amountVal,merchantID : merchantIDVal, merchantkey : merchantKeyVal, salt: saltVal, userName: nameVal, productInfo: productInfoVal, email: emailVal, contactNo: mobileVal,isProduction: isProductionVal == 1, fromController: topVC) { (response, transactionID, error) in
                                                            result(transactionID)
                                                        }
                                                    }
              }
          }
          else {
              result("Failed to get top controller")
          }
      }
}

==> 0.0.26.tar.gz: ios/Classes/SwiftSpectusPayumoneyPlugin.swift <==
import Flutter
import UIKit

public class SwiftSpectusPayumoneyPlugin: NSObject, FlutterPlugin {
  public static func register(with registrar: FlutterPluginRegistrar) {
    let channel = FlutterMethodChannel(name: "spectus_payumoney_plugin", binaryMessenger: registrar.messenger())
    let instance = SwiftSpectusPayumoneyPlugin()
    registrar.addMethodCallDelegate(instance, channel: channel)
  }

  public func handle(_ call: FlutterMethodCall, result: @escaping FlutterResult) {
          if (call.method == "getPlatformVersion") {
              result("iOS " + UIDevice.current.systemVersion)
          }
          else if (call.method == "payUmoneyPayment") {
              //result("\(checkiOSReturn())")
              if let topVC = UIApplication.shared.windows[0].rootViewController {

                  guard let args = call.arguments else {
                      return
                  }
                  if let myArgs = args as? [String: Any], let amountVal = myArgs["amount"] as? String,let merchantIDVal = myArgs["merchantID"] as? String,let merchantKeyVal = myArgs["merchantKey"] as? String,let saltVal = myArgs["salt"] as? String, let nameVal = myArgs["name"] as? String, let productInfoVal = myArgs["productInfo"] as? String, let emailVal = myArgs["email"] as? String, let mobileVal = myArgs["mobile"] as? String, let isProductionVal = myArgs["environmentMode"] as? Int {
                                      startPaymentWithAmount(amountVal,merchantID : merchantIDVal, merchantkey : merchantKeyVal, salt: saltVal, userName: nameVal, productInfo: productInfoVal, email: emailVal, contactNo: mobileVal,isProduction: isProductionVal == 1, buttonTextOnSuccess: "", fromController: topVC) { (response, transactionID, error) in
                                                            result(transactionID)
                                                        }
                                                    }
              }
          }
          else {
              result("Failed to get top controller")
          }
      }
}
